@@ -1,6 +1,5 @@
 /*
  * realpath.c
- * $Id$
  *
  * Copyright (c) 2009 The MacPorts Project.
  * All rights reserved.
@@ -36,6 +35,7 @@
 
 /* required for PATH_MAX and realpath(3) */
 #define _XOPEN_SOURCE 500
+#define _DARWIN_C_SOURCE
 
 #include <tcl.h>
 
@@ -53,7 +53,7 @@
  * @param objc			number of parameters
  * @param objv			parameters
  */
-int RealpathCmd(ClientData clientData UNUSED, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
+int RealpathCmd(ClientData clientData UNUSED, Tcl_Interp *interp, int objc, Tcl_Obj *const objv[])
 {
     const char error_message[] = "realpath failed: ";
     Tcl_Obj *tcl_result;
@@ -63,6 +63,7 @@ int RealpathCmd(ClientData clientData UNUSED, Tcl_Interp *interp, int objc, Tcl_
 
     if (objc != 2) {
         Tcl_WrongNumArgs(interp, 1, objv, "path");
+        free(rpath);
         return TCL_ERROR;
     }
 
